% Auto-generated chapter 22 for abudawud
% Hadiths in this chapter: 84

\hadithdefcmd{abudawud}{3242}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ مَصْبُورَةٍ كَاذِبًا فَلْيَتَبَوَّأْ بِوَجْهِهِ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{3242}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Imran ibn Husayn: The Prophet (ﷺ) said: If anyone swears a false oath in confinement, he should make his seat in Hell on account of his (act)}}
\hadithdefcmd{abudawud}{3243}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، وَهَنَّادُ بْنُ السَّرِيِّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ هُوَ فِيهَا فَاجِرٌ لِيَقْتَطِعَ بِهَا مَالَ امْرِئٍ مُسْلِمٍ لَقِيَ اللَّهَ وَهُوَ عَلَيْهِ غَضْبَانُ ‏"‏ ‏.‏ فَقَالَ الأَشْعَثُ فِيَّ وَاللَّهِ كَانَ ذَلِكَ كَانَ بَيْنِي وَبَيْنَ رَجُلٍ مِنَ الْيَهُودِ أَرْضٌ فَجَحَدَنِي فَقَدَّمْتُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لِيَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ لِلْيَهُودِيِّ ‏"‏ احْلِفْ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِذًا يَحْلِفُ وَيَذْهَبُ بِمَالِي فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{3243}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2416، 2417) Sahih Muslim (138)}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Messenger of Allah (ﷺ) said: He who swears an oath in which he tells a lie to take the property of a Muslim by unfair means, will meet Allah while He is angry with him. Al-Ash'ath said: I swear by Allah, he said this about me. There was some land between me and a Jew, but he denied it to me; so I presented him to the Prophet (ﷺ). The Prophet (ﷺ) asked me: Have you any evidence? I replied: No. He said to the Jew: Take an oath. I said: Messenger of Allah, now he will take an oath and take my property. So Allah, the Exalted, revealed the verse, "As for those who sell the faith they owe to Allah and their own plighted word for a small price, they shall have no portion in the hereafter}}
\hadithdefcmd{abudawud}{3244}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا الْفِرْيَابِيُّ، حَدَّثَنَا الْحَارِثُ بْنُ سُلَيْمَانَ، حَدَّثَنِي كُرْدُوسٌ، عَنِ الأَشْعَثِ بْنِ قَيْسٍ، أَنَّ رَجُلاً، مِنْ كِنْدَةَ وَرَجُلاً مِنْ حَضْرَمَوْتَ اخْتَصَمَا إِلَى النَّبِيِّ صلى الله عليه وسلم فِي أَرْضٍ مِنَ الْيَمَنِ فَقَالَ الْحَضْرَمِيُّ يَا رَسُولَ اللَّهِ إِنَّ أَرْضِي اغْتَصَبَنِيهَا أَبُو هَذَا وَهِيَ فِي يَدِهِ ‏.‏ قَالَ ‏"‏ هَلْ لَكَ بَيِّنَةٌ ‏"‏ ‏.‏ قَالَ لاَ وَلَكِنْ أُحَلِّفُهُ وَاللَّهِ مَا يَعْلَمُ أَنَّهَا أَرْضِي اغْتَصَبَنِيهَا أَبُوهُ فَتَهَيَّأَ الْكِنْدِيُّ لِلْيَمِينِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَقْتَطِعُ أَحَدٌ مَالاً بِيَمِينٍ إِلاَّ لَقِيَ اللَّهَ وَهُوَ أَجْذَمُ ‏"‏ ‏.‏ فَقَالَ الْكِنْدِيُّ هِيَ أَرْضُهُ ‏.‏\hadithno{3244}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Ash'ath ibn Qays: A man of Kindah and a man of Hadramawt brought their dispute to the Prophet (ﷺ) about a land in the Yemen. Al-Hadrami said: Messenger of Allah, the father of this (man) usurped my land and it is in his possession. The Prophet asked: Have you any evidence? Al-Hadrami replied: No, but I make him swear (that he should say) that he does not know that it is my land which his father usurped from me. Al-Kindi became ready to take the oath. The Messenger of Allah (ﷺ) said: If anyone usurps the property by taking an oath, he will meet Allah while his hand is mutilated. Al-Kindi then said: It is his land}}
\hadithdefcmd{abudawud}{3245}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلِ بْنِ حُجْرٍ الْحَضْرَمِيِّ، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ مِنْ حَضْرَمَوْتَ وَرَجُلٌ مِنْ كِنْدَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ الْحَضْرَمِيُّ يَا رَسُولَ اللَّهِ إِنَّ هَذَا غَلَبَنِي عَلَى أَرْضٍ كَانَتْ لأَبِي ‏.‏ فَقَالَ الْكِنْدِيُّ هِيَ أَرْضِي فِي يَدِي أَزْرَعُهَا لَيْسَ لَهُ فِيهَا حَقٌّ ‏.‏ قَالَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِلْحَضْرَمِيِّ ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَلَكَ يَمِينُهُ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّهُ فَاجِرٌ لاَ يُبَالِي مَا حَلَفَ عَلَيْهِ لَيْسَ يَتَوَرَّعُ مِنْ شَىْءٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَيْسَ لَكَ مِنْهُ إِلاَّ ذَاكَ ‏"‏ ‏.‏ فَانْطَلَقَ لِيَحْلِفَ لَهُ فَلَمَّا أَدْبَرَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا لَئِنْ حَلَفَ عَلَى مَالٍ لِيَأْكُلَهُ ظَالِمًا لَيَلْقَيَنَّ اللَّهَ عَزَّ وَجَلَّ وَهُوَ عَنْهُ مُعْرِضٌ ‏"‏ ‏.‏\hadithno{3245}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (139)}\hadithtrans{Narrated 'Alqamah b. Wa'il b. Hujr al-Hadrami:On the Authority of his father: A man from Hadramawt and a man of Kindah came to the Messenger of Allah (ﷺ). Al-Hadrami said: Messenger of Allah, this (man) took away forcibly from me the land which belongs to my father. Al-Kindi said: It is my land in my possession, and I cultivate it, he has no right to it. The Prophet (ﷺ) then said to al-Hadrami: Have you any proof ? He said: No. He then said: So for you is his oath. He said: Messenger of Allah, he is liar, he does not care for which he is taking the oath. He does not refrain himself from anything. The Prophet (ﷺ) said: You will have nothing from him except that. He went to take an oath for him. When he turned his back, the Messenger of Allah (ﷺ) said: If he takes an oath on the property to take it away by unfair means, he will meet Allah while He is unmindful of him}}
\hadithdefcmd{abudawud}{3246}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هَاشِمُ بْنُ هَاشِمٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ نِسْطَاسٍ، مِنْ آلِ كَثِيرِ بْنِ الصَّلْتِ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَحْلِفُ أَحَدٌ عِنْدَ مِنْبَرِي هَذَا عَلَى يَمِينٍ آثِمَةٍ وَلَوْ عَلَى سِوَاكٍ أَخْضَرَ إِلاَّ تَبَوَّأَ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏ أَوْ ‏"‏ وَجَبَتْ لَهُ النَّارُ ‏"‏ ‏.‏\hadithno{3246}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: One should not take a false oath at this pulpit of mine even on a green tooth-stick; otherwise he will make his abode in Hell, or Hell will be certain for him}}
\hadithdefcmd{abudawud}{3247}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ فَقَالَ فِي حَلِفِهِ وَاللاَّتِ فَلْيَقُلْ لاَ إِلَهَ إِلاَّ اللَّهُ وَمَنْ قَالَ لِصَاحِبِهِ تَعَالَ أُقَامِرْكَ فَلْيَتَصَدَّقْ بِشَىْءٍ ‏"‏ ‏.‏\hadithno{3247}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1647)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: If anyone swears on oath is the course which he says: "By al-Lat" he should say: There is no god but Allah, and that if anyone says to his friend: Come and let me play for money with you, he should give something in charity (sadaqah)}}
\hadithdefcmd{abudawud}{3248}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَوْفٌ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحْلِفُوا بِآبَائِكُمْ وَلاَ بِأُمَّهَاتِكُمْ وَلاَ بِالأَنْدَادِ وَلاَ تَحْلِفُوا إِلاَّ بِاللَّهِ وَلاَ تَحْلِفُوا بِاللَّهِ إِلاَّ وَأَنْتُمْ صَادِقُونَ ‏"‏ ‏.‏\hadithno{3248}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Do not swear by your fathers, or by your mothers, or by rivals to Allah; and swear by Allah only, and swear by Allah only when you are speaking the truth}}
\hadithdefcmd{abudawud}{3249}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَدْرَكَهُ وَهُوَ فِي رَكْبٍ وَهُوَ يَحْلِفُ بِأَبِيهِ فَقَالَ ‏ "‏ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ فَمَنْ كَانَ حَالِفًا فَلْيَحْلِفْ بِاللَّهِ أَوْ لِيَسْكُتْ ‏"‏ ‏.‏\hadithno{3249}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6108) Sahih Muslim (1646)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) found 'Umar al-Khattab in a caravan while he was swearing by his father. So he said: Allah forbids you to swear by forefathers. If anyone swears, he must swear by Allah or keep silence}}
\hadithdefcmd{abudawud}{3250}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنْ عُمَرَ، - رضى الله عنه - قَالَ سَمِعَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم نَحْوَ مَعْنَاهُ إِلَى ‏ "‏ بِآبَائِكُمْ ‏"‏ ‏.‏ زَادَ قَالَ عُمَرُ فَوَاللَّهِ مَا حَلَفْتُ بِهَذَا ذَاكِرًا وَلاَ آثِرًا ‏.‏\hadithno{3250}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1646)}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn 'Umar through a different chain of narrators to the same effect up to the words "by your fathers". This version adds:" 'Umar said: I swear by Allah, I never swore by it personally or reporting it from others}}
\hadithdefcmd{abudawud}{3251}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ سَمِعْتُ الْحَسَنَ بْنَ عُبَيْدِ اللَّهِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، قَالَ سَمِعَ ابْنُ عُمَرَ، رَجُلاً يَحْلِفُ لاَ وَالْكَعْبَةِ فَقَالَ لَهُ ابْنُ عُمَرَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ حَلَفَ بِغَيْرِ اللَّهِ فَقَدْ أَشْرَكَ ‏"‏ ‏.‏\hadithno{3251}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Sa'id ibn Ubaydah said:Ibn Umar heard a man swearing: No, I swear by the Ka'bah. Ibn Umar said to him: I heard the Messenger of Allah (ﷺ) say: He who swears by anyone but Allah is polytheist}}
\hadithdefcmd{abudawud}{3252}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ الْمَدَنِيُّ، عَنْ أَبِي سُهَيْلٍ، نَافِعِ بْنِ مَالِكِ بْنِ أَبِي عَامِرٍ عَنْ أَبِيهِ، أَنَّهُ سَمِعَ طَلْحَةَ بْنَ عُبَيْدِ اللَّهِ يَعْنِي فِي، حَدِيثِ قِصَّةِ الأَعْرَابِيِّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَفْلَحَ وَأَبِيهِ إِنْ صَدَقَ دَخَلَ الْجَنَّةَ وَأَبِيهِ إِنْ صَدَقَ ‏"‏ ‏.‏\hadithno{3252}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{Referring to the story of a bedouin, Talhah b. 'Ubaid Allah reported the Prophet (ﷺ) as saying:He became successful, by his father, if he speaks the truth, he will enter paradise, by his father, if he speaks truth}}
\hadithdefcmd{abudawud}{3253}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا الْوَلِيدُ بْنُ ثَعْلَبَةَ الطَّائِيُّ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ بِالأَمَانَةِ فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{3253}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Buraydah ibn al-Hasib: The Prophet (ﷺ) said: He who swears by Amanah (faithfulness) is not one of us}}
\hadithdefcmd{abudawud}{3254}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ الشَّامِيُّ، حَدَّثَنَا حَسَّانُ، - يَعْنِي ابْنَ إِبْرَاهِيمَ - حَدَّثَنَا إِبْرَاهِيمُ، - يَعْنِي الصَّائِغَ - عَنْ عَطَاءٍ، فِي اللَّغْوِ فِي الْيَمِينِ قَالَ قَالَتْ عَائِشَةُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ هُوَ كَلاَمُ الرَّجُلِ فِي بَيْتِهِ كَلاَّ وَاللَّهِ وَبَلَى وَاللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ كَانَ إِبْرَاهِيمُ الصَّائِغُ رَجُلاً صَالِحًا قَتَلَهُ أَبُو مُسْلِمٍ بِعَرَنْدَسَ قَالَ وَكَانَ إِذَا رَفَعَ الْمَطْرَقَةَ فَسَمِعَ النِّدَاءَ سَيَّبَهَا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ دَاوُدُ بْنُ أَبِي الْفُرَاتِ عَنْ إِبْرَاهِيمَ الصَّائِغِ مَوْقُوفًا عَلَى عَائِشَةَ وَكَذَلِكَ رَوَاهُ الزُّهْرِيُّ وَعَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ وَمَالِكُ بْنُ مِغْوَلٍ وَكُلُّهُمْ عَنْ عَطَاءٍ عَنْ عَائِشَةَ مَوْقُوفًا ‏.‏\hadithno{3254}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said about the futile oath: It is man's speech in his house: No, by Allah, and Yes, by Allah. Abu Dawud said: Ibrahim al-Sa'igh, the narrator of this tradition , was a pious man. Abu Muslim killed him at 'Aranda. When he raised a hammed and heard the call to prayer, he gave it up. Abu Dawud said: This tradition has been transmitted by Dawud b. Abi al-Furat from Ibrahim al-Sa'igh as a statement of 'Aishah (not attributed to the Prophet). Similarly, it has been transmitted by al-Zuhri, 'Abd al-Malik b. Abi Sulaiman and Malik b. Mughul. All of them transmitted it from 'Ata on the authority of 'Aishah on her own statement}}
\hadithdefcmd{abudawud}{3255}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، قَالَ أَنَا هُشَيْمٌ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا هُشَيْمٌ، عَنْ عَبَّادِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَمِينُكَ عَلَى مَا يُصَدِّقُكَ عَلَيْهَا صَاحِبُكَ ‏"‏ ‏.‏ قَالَ مُسَدَّدٌ قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي صَالِحٍ ‏.‏ قَالَ أَبُو دَاوُدَ هُمَا وَاحِدٌ عَبْدُ اللَّهِ بْنُ أَبِي صَالِحٍ وَعَبَّادُ بْنُ أَبِي صَالِحٍ ‏.‏\hadithno{3255}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1653)}\hadithtrans{Narrated Abu Hurairah: The Messenger of Allah (ﷺ) as saying: Your oath should be about something regarding which your companion will believe you. Musaddad said: 'Abd Allah b. Abi Salih narrated to me. Abu Dawud said: Both of them refer to the same person: 'Abbad b. Abu Salih and 'Abd Allah b. Abi Salih}}
\hadithdefcmd{abudawud}{3256}{حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ النَّاقِدُ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ الأَعْلَى، عَنْ جَدَّتِهِ، عَنْ أَبِيهَا، سُوَيْدِ بْنِ حَنْظَلَةَ قَالَ خَرَجْنَا نُرِيدُ رَسُولَ اللَّهِ وَمَعَنَا وَائِلُ بْنُ حُجْرٍ فَأَخَذَهُ عَدُوٌّ لَهُ فَتَحَرَّجَ الْقَوْمُ أَنْ يَحْلِفُوا وَحَلَفْتُ أَنَّهُ أَخِي فَخَلَّى سَبِيلَهُ فَأَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ أَنَّ الْقَوْمَ تَحَرَّجُوا أَنْ يَحْلِفُوا وَحَلَفْتُ أَنَّهُ أَخِي قَالَ ‏ "‏ صَدَقْتَ الْمُسْلِمُ أَخُو الْمُسْلِمِ ‏"‏ ‏.‏\hadithno{3256}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Suwayd ibn Hanzalah: We went out intending (to visit) the Messenger of Allah (ﷺ) and Wa'il ibn Hujr was with us. His enemy caught him. The people desisted from swearing an oath, but I took an oath that he was my brother. So he left him. We then came to the Messenger of Allah (ﷺ), and I informed him that the people desisted from taking the oath, but I swore that he was my brother. He said: You spoke the truth: A Muslim is a brother of a Muslim}}
\hadithdefcmd{abudawud}{3257}{حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ سَلاَّمٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ أَخْبَرَنِي أَبُو قِلاَبَةَ، أَنَّ ثَابِتَ بْنَ الضَّحَّاكِ، أَخْبَرَهُ أَنَّهُ، بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم تَحْتَ الشَّجَرَةِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ بِمِلَّةٍ غَيْرِ مِلَّةِ الإِسْلاَمِ كَاذِبًا فَهُوَ كَمَا قَالَ وَمَنْ قَتَلَ نَفْسَهُ بِشَىْءٍ عُذِّبَ بِهِ يَوْمَ الْقِيَامَةِ وَلَيْسَ عَلَى رَجُلٍ نَذْرٌ فِيمَا لاَ يَمْلِكُهُ ‏"‏ ‏.‏\hadithno{3257}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4171) Sahih Muslim (110)}\hadithtrans{Narrated Thabit bin Adh-Dahhak:That he took oath of allegiance to the Messenger of Allah (ﷺ) under the tree. The Messenger of Allah (ﷺ) said: If anyone swears by religion other than Islam falsely, he is like what has has said. If anyone kills himself with something, he will be punished with it on the Day of Resurrection. A vow over which a man has no control is not binding on him}}
\hadithdefcmd{abudawud}{3258}{حَدَّثَنِي أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا حُسَيْنٌ، - يَعْنِي ابْنَ وَاقِدٍ - حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ مَنْ حَلَفَ فَقَالَ إِنِّي بَرِيءٌ مِنَ الإِسْلاَمِ فَإِنْ كَانَ كَاذِبًا فَهُوَ كَمَا قَالَ، وَإِنْ كَانَ صَادِقًا فَلَنْ يَرْجِعَ إِلَى الإِسْلاَمِ سَالِمًا ‏"‏ ‏.‏\hadithno{3258}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Buraydah ibn al-Hasib: The Prophet (ﷺ) said: If anyone takes an oath and says: I am free from Islam; now if he is a liar (in his oath), he will not return to Islam with soundness}}
\hadithdefcmd{abudawud}{3259}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا يَحْيَى بْنُ الْعَلاَءِ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ يُوسُفَ بْنِ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، قَالَ ‏:‏ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَضَعَ تَمْرَةً عَلَى كِسْرَةٍ فَقَالَ ‏:‏ ‏ "‏ هَذِهِ إِدَامُ هَذِهِ ‏"‏ ‏.‏\hadithno{3259}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Yusuf ibn Abdullah ibn Salam: I saw that the Prophet (ﷺ) put a date on a loaf and said: This is a thing eaten with bread (condiments)}}
\hadithdefcmd{abudawud}{3260}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ أَبِي يَحْيَى، عَنْ يَزِيدَ الأَعْوَرِ، عَنْ يُوسُفَ بْنِ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، مِثْلَهُ ‏.‏\hadithno{3260}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been transmitted by Yusuf b. 'Abd Allah b. Salam through a different chain of narrators}}
\hadithdefcmd{abudawud}{3261}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَقَالَ إِنْ شَاءَ اللَّهُ فَقَدِ اسْتَثْنَى ‏"‏ ‏.‏\hadithno{3261}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: If anyone says when swearing an oath: "If Allah wills," he makes an exception}}
\hadithdefcmd{abudawud}{3262}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، وَمُسَدَّدٌ، - وَهَذَا حَدِيثُهُ - قَالاَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ مَنْ حَلَفَ فَاسْتَثْنَى فَإِنْ شَاءَ رَجَعَ، وَإِنْ شَاءَ تَرَكَ غَيْرَ حِنْثٍ ‏"‏ ‏.‏\hadithno{3262}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: If anyone swears an oath and makes an exception, he may fulfil it if he wishes and break it if he wishes without any accountability for breaking}}
\hadithdefcmd{abudawud}{3263}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ ‏:‏ أَكْثَرُ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَحْلِفُ بِهَذِهِ الْيَمِينِ ‏:‏ ‏ "‏ لاَ، وَمُقَلِّبِ الْقُلُوبِ ‏"‏ ‏.‏\hadithno{3263}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6617)}\hadithtrans{Narrated Ibn 'Umar:The oath which the Messenger of Allah (ﷺ) often used was this: No, by Him who overturns the hearts}}
\hadithdefcmd{abudawud}{3264}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ عَاصِمِ بْنِ شُمَيْخٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ ‏:‏ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اجْتَهَدَ فِي الْيَمِينِ قَالَ ‏:‏ ‏ "‏ وَالَّذِي نَفْسُ أَبِي الْقَاسِمِ بِيَدِهِ ‏"‏ ‏.‏\hadithno{3264}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: When the Messenger of Allah (ﷺ) swore an oath strongly, he said: No, by Him in Whose hand is the soul of AbulQasim}}
\hadithdefcmd{abudawud}{3265}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي رِزْمَةَ، أَخْبَرَنِي زَيْدُ بْنُ حُبَابٍ، أَخْبَرَنِي مُحَمَّدُ بْنُ هِلاَلٍ، حَدَّثَنِي أَبِي أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ ‏:‏ كَانَتْ يَمِينُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا حَلَفَ يَقُولُ ‏:‏ ‏ "‏ لاَ، وَأَسْتَغْفِرُ اللَّهَ ‏"‏ ‏.‏\hadithno{3265}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: When the Messenger of Allah (ﷺ) swore an oath, it was: No, and I beg forgiveness of Allah}}
\hadithdefcmd{abudawud}{3266}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَيَّاشٍ السَّمَعِيُّ الأَنْصَارِيُّ، عَنْ دَلْهَمِ بْنِ الأَسْوَدِ بْنِ عَبْدِ اللَّهِ بْنِ حَاجِبِ بْنِ عَامِرِ بْنِ الْمُنْتَفِقِ الْعُقَيْلِيِّ، عَنْ أَبِيهِ، عَنْ عَمِّهِ، لَقِيطِ بْنِ عَامِرٍ قَالَ دَلْهَمٌ وَحَدَّثَنِيهِ أَيْضًا الأَسْوَدُ بْنُ عَبْدِ اللَّهِ، عَنْ عَاصِمِ بْنِ لَقِيطٍ، ‏:‏ أَنَّ لَقِيطَ بْنَ عَامِرٍ، خَرَجَ وَافِدًا إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ لَقِيطٌ ‏:‏ فَقَدِمْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ حَدِيثًا فِيهِ ‏:‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏ "‏ لَعَمْرُ إِلَهِكَ ‏"‏ ‏.‏\hadithno{3266}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Laqit ibn Amir: We came to the Messenger of Allah (ﷺ) in a delegation. The Prophet (ﷺ) then said: By the age of thy god}}
\hadithdefcmd{abudawud}{3267}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، ‏:‏ أَنَّ أَبَا بَكْرٍ، أَقْسَمَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏ "‏ لاَ تُقْسِمْ ‏"‏ ‏.‏\hadithno{3267}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7046) Sahih Muslim (2269)}\hadithtrans{Narrated Abdullah ibn Abbas: AbuBakr adjured the Prophet (ﷺ). The Prophet (ﷺ) said: Do not adjure an oath}}
\hadithdefcmd{abudawud}{3268}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - قَالَ ابْنُ يَحْيَى كَتَبْتُهُ مِنْ كِتَابِهِ - أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏:‏ كَانَ أَبُو هُرَيْرَةَ يُحَدِّثُ أَنَّ رَجُلاً، أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏:‏ إِنِّي أَرَى اللَّيْلَةَ فَذَكَرَ رُؤْيَا فَعَبَّرَهَا أَبُو بَكْرٍ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏"‏ أَصَبْتَ بَعْضًا وَأَخْطَأْتَ بَعْضًا ‏"‏ ‏.‏ فَقَالَ ‏:‏ أَقْسَمْتُ عَلَيْكَ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ لَتُحَدِّثَنِّي مَا الَّذِي أَخْطَأْتُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏"‏ لاَ تُقْسِمْ ‏"‏ ‏.‏\hadithno{3268}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7000) Sahih Muslim (2269)}\hadithtrans{Narrated Ibn 'Abbas:Abu Hurairah narrated that a man came to the Messenger of Allah (ﷺ) and said: I had a dream last night, and he then mentioned it. So Abu Bakr interpreted it. The Prophet (ﷺ) said: You are partly right and partly wrong. He then said: I adjure you, Messenger of Allah, may my father be sacrificed on you, do tell me the mistake I have committed. The Prophet (ﷺ) said: Do not adjure}}
\hadithdefcmd{abudawud}{3269}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُلَيْمَانُ بْنُ كَثِيرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ لَمْ يَذْكُرِ الْقَسَمَ، زَادَ فِيهِ وَلَمْ يُخْبِرْهُ ‏.‏\hadithno{3269}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2269)}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn 'Abbas through a different chain of narrators. In this version there is no mention of the word qasam (oath). It has the words:"He did not inform him}}
\hadithdefcmd{abudawud}{3270}{حَدَّثَنَا مُؤَمَّلُ بْنُ هِشَامٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي عُثْمَانَ، أَوْ عَنْ أَبِي السَّلِيلِ، عَنْهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، قَالَ ‏:‏ نَزَلَ بِنَا أَضْيَافٌ لَنَا قَالَ ‏:‏ وَكَانَ أَبُو بَكْرٍ يَتَحَدَّثُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِاللَّيْلِ فَقَالَ ‏:‏ لاَ أَرْجِعَنَّ إِلَيْكَ حَتَّى تَفْرَغَ مِنْ ضِيَافَةِ هَؤُلاَءِ وَمِنْ قِرَاهُمْ فَأَتَاهُمْ بِقِرَاهُمْ فَقَالُوا ‏:‏ لاَ نَطْعَمُهُ حَتَّى يَأْتِيَ أَبُو بَكْرٍ ‏.‏ فَجَاءَ فَقَالَ ‏:‏ مَا فَعَلَ أَضْيَافُكُمْ أَفَرَغْتُمْ مِنْ قِرَاهُمْ قَالُوا ‏:‏ لاَ ‏.‏ قُلْتُ ‏:‏ قَدْ أَتَيْتُهُمْ بِقِرَاهُمْ فَأَبَوْا وَقَالُوا ‏:‏ وَاللَّهِ لاَ نَطْعَمُهُ حَتَّى يَجِيءَ، فَقَالُوا ‏:‏ صَدَقَ قَدْ أَتَانَا بِهِ فَأَبَيْنَا حَتَّى تَجِيءَ، قَالَ ‏:‏ فَمَا مَنَعَكُمْ قَالُوا ‏:‏ مَكَانُكَ ‏.‏ قَالَ ‏:‏ وَاللَّهِ لاَ أَطْعَمُهُ اللَّيْلَةَ، قَالَ فَقَالُوا ‏:‏ وَنَحْنُ وَاللَّهِ لاَ نَطْعَمُهُ حَتَّى تَطْعَمَهُ ‏.‏ قَالَ ‏:‏ مَا رَأَيْتُ فِي الشَّرِّ كَاللَّيْلَةِ قَطُّ - قَالَ - قَرِّبُوا طَعَامَكُمْ ‏.‏ قَالَ ‏:‏ فَقُرِّبَ طَعَامُهُمْ فَقَالَ ‏:‏ بِسْمِ اللَّهِ فَطَعِمَ وَطَعِمُوا فَأُخْبِرْتُ أَنَّهُ أَصْبَحَ فَغَدَا عَلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَهُ بِالَّذِي صَنَعَ وَصَنَعُوا، قَالَ ‏:‏ ‏ "‏ بَلْ أَنْتَ أَبَرُّهُمْ وَأَصْدَقُهُمْ ‏"‏ ‏.‏\hadithno{3270}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6140) Sahih Muslim (2057)}\hadithtrans{Narrated 'Abd al-Rahman b. Abi Bakr:Some guests visited us, and Abu Bakr was conversing with the Messenger of Allah (ﷺ) at night. He (Abu Bakr) said: I will not return to you until you are free from their entertainment and serving them food. So he brought them food, but they said: We shall not eat it until Abu Bakr comes (back). Abu Bakr then came and asked: What did your guest do? Are you free from their entertainment ? They said: No. I said: I brought them food, but they refused and said: We swear by Allah, we shall not take it until he comes. They said: He spoke the truth. He brought it to us, but we refused (to take it) until you come. He asked: What did prevent you ? He said: I swear by Allah, I shall not take food tonight. They said: And we also swear by Allah that we shall not take food until you take it. He said: I never saw an evil like the one tonight. He said: Bring your food near (you). He ('Abd al-Rahman) said: Their food was then brought near them. He said: In the name of Allah, and he took the food, and they also took it. I then informed him that the dawn had broken. So he went to th Prophet (ﷺ) and informed him of what he and they had done. He said: You are the most obedient and most trustful of them}}
\hadithdefcmd{abudawud}{3271}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا سَالِمُ بْنُ نُوحٍ، وَعَبْدُ الأَعْلَى، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي عُثْمَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، بِهَذَا الْحَدِيثِ نَحْوَهُ زَادَ عَنْ سَالِمٍ، فِي حَدِيثِهِ قَالَ ‏:‏ وَلَمْ يَبْلُغْنِي كَفَّارَةً ‏.‏\hadithno{3271}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2057)}\hadithtrans{A similar tradition has also been transmitted by 'Abd al-Rahman b. Abi Bakr through a different chain of narrators. This version adds on the authority of Salim:"Expiation (for breaking the oath) has not reached me}}
\hadithdefcmd{abudawud}{3272}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمِنْهَالِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حَبِيبٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، ‏:‏ أَنَّ أَخَوَيْنِ، مِنَ الأَنْصَارِ كَانَ بَيْنَهُمَا مِيرَاثٌ فَسَأَلَ أَحَدُهُمَا صَاحِبَهُ الْقِسْمَةَ فَقَالَ ‏:‏ إِنْ عُدْتَ تَسْأَلُنِي عَنِ الْقِسْمَةِ فَكُلُّ مَالٍ لِي فِي رِتَاجِ الْكَعْبَةِ ‏.‏ فَقَالَ لَهُ عُمَرُ ‏:‏ إِنَّ الْكَعْبَةَ غَنِيَّةٌ عَنْ مَالِكَ، كَفِّرْ عَنْ يَمِينِكَ وَكَلِّمْ أَخَاكَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏:‏ ‏ "‏ لاَ يَمِينَ عَلَيْكَ، وَلاَ نَذْرَ فِي مَعْصِيَةِ الرَّبِّ وَفِي قَطِيعَةِ الرَّحِمِ وَفِيمَا لاَ تَمْلِكُ ‏"‏ ‏.‏\hadithno{3272}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sa'id ibn al-Musayyab said:There were two brothers among the Ansar who shared an inheritance. When one of them asked the other for the portion due to him, he replied: If you ask me again for the portion due to you, all my property will be devoted to the decoration of the Ka'bah. Umar said to him: The Ka'bah does not need your property. Make atonement for your oath and speak to your brother. I heard the Messenger of Allah (ﷺ) say: An oath or vow to disobey the Lord, or to break ties of relationship or about something over which one has no control is not binding on you}}
\hadithdefcmd{abudawud}{3273}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنِي أَبِي عَبْدُ الرَّحْمَنِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ لاَ نَذْرَ إِلاَّ فِيمَا يُبْتَغَى بِهِ وَجْهُ اللَّهِ، وَلاَ يَمِينَ فِي قَطِيعَةِ رَحِمٍ ‏"‏ ‏.‏\hadithno{3273}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) said: A vow is binding in those things by which the pleasure of Allah is sought, and an oath to break ties of relationship is not binding}}
\hadithdefcmd{abudawud}{3274}{حَدَّثَنَا الْمُنْذِرُ بْنُ الْوَلِيدِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَكْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ الأَخْنَسِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ لاَ نَذْرَ وَلاَ يَمِينَ فِيمَا لاَ يَمْلِكُ ابْنُ آدَمَ وَلاَ فِي مَعْصِيَةِ اللَّهِ وَلاَ فِي قَطِيعَةِ رَحِمٍ، وَمَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيَدَعْهَا وَلْيَأْتِ الَّذِي هُوَ خَيْرٌ، فَإِنَّ تَرْكَهَا كَفَّارَتُهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ الأَحَادِيثُ كُلُّهَا عَنِ النَّبِيِّ صلى الله عليه وسلم ‏:‏ ‏"‏ وَلْيُكَفِّرْ عَنْ يَمِينِهِ ‏"‏ ‏.‏ إِلاَّ فِيمَا لاَ يُعْبَأُ بِهِ ‏.‏ قَالَ أَبُو دَاوُدَ قُلْتُ لأَحْمَدَ ‏:‏ رَوَى يَحْيَى بْنُ سَعِيدٍ عَنْ يَحْيَى بْنِ عُبَيْدِ اللَّهِ فَقَالَ ‏:‏ تَرَكَهُ بَعْدَ ذَلِكَ وَكَانَ أَهْلاً لِذَلِكَ، قَالَ أَحْمَدُ ‏:‏ أَحَادِيثُهُ مَنَاكِيرُ وَأَبُوهُ لاَ يُعْرَفُ ‏.‏\hadithno{3274}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) said: An oath or a vow about something over which a human being has no control, and to disobey Allah, and to break ties of relationship is not binding. If anyone takes an oath and then considers something else better than it, he should give it up, and do what is better, for leaving it is its atonement. Abu Dawud said: All sound traditions from the Prophet (ﷺ) say: "He should make atonement for his oath," except those versions which are not reliable. Abu Dawud said: I said to Ahmad: Yahya b. Sa'id (al-Qattan) has transmitted this tradition from Yahya b. 'Ubaid Allah. He (Ahmad b. Hanbal) said: But he gave it up after that, and he was competent for doing it. Ahmad said: His (Yahya b. 'Ubaid Allah's) tradition are munkar (rejected) and his father is not known}}
\hadithdefcmd{abudawud}{3275}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ أَبِي يَحْيَى، عَنِ ابْنِ عَبَّاسٍ، ‏:‏ أَنَّ رَجُلَيْنِ، اخْتَصَمَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَسَأَلَ النَّبِيُّ صلى الله عليه وسلم الطَّالِبَ الْبَيِّنَةَ، فَلَمْ تَكُنْ لَهُ بَيِّنَةٌ فَاسْتَحْلَفَ الْمَطْلُوبَ فَحَلَفَ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ بَلَى قَدْ فَعَلْتَ، وَلَكِنْ قَدْ غُفِرَ لَكَ بِإِخْلاَصِ قَوْلِ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ يُرَادُ مِنْ هَذَا الْحَدِيثِ أَنَّهُ لَمْ يَأْمُرْهُ بِالْكَفَّارَةِ ‏.‏\hadithno{3275}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: Two men brought their dispute to the Prophet (ﷺ). The Prophet (ﷺ) asked the plaintiff to produce evidence, but he had no evidence. So he asked the defendant to swear. He swore by Allah "There is no god but He." The Messenger of Allah (ﷺ) said: Yes, you have done it, but you have been forgiven for the sincerity of the statement: "There is no god but Allah." Abu Dawud said: This tradition means that he did not command him to make atonement}}
\hadithdefcmd{abudawud}{3276}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا غَيْلاَنُ بْنُ جَرِيرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏:‏ ‏"‏ إِنِّي وَاللَّهِ إِنْ شَاءَ اللَّهُ لاَ أَحْلِفُ عَلَى يَمِينٍ فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا إِلاَّ كَفَّرْتُ عَنْ يَمِينِي، وَأَتَيْتُ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏ أَوْ قَالَ ‏:‏ ‏"‏ إِلاَّ أَتَيْتُ الَّذِي هُوَ خَيْرٌ وَكَفَّرْتُ يَمِينِي ‏"‏ ‏.‏\hadithno{3276}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6623) Sahih Muslim (1649)}\hadithtrans{Narrated Abu Burdah:On the authority of his father that the Prophet (ﷺ) said: I swear by Allah that if Allah wills I shall swear on an oath and then consider something else to be better than it without making atonement for my oath and doing the thing that is better. Or he said (according to another version): But doing the thing that is better and making atonement for my oath}}
\hadithdefcmd{abudawud}{3277}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يُونُسُ، وَمَنْصُورٌ، - يَعْنِي ابْنَ زَاذَانَ - عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ قَالَ لِيَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏ "‏ يَا عَبْدَ الرَّحْمَنِ بْنَ سَمُرَةَ إِذَا حَلَفْتَ عَلَى يَمِينٍ فَرَأَيْتَ غَيْرَهَا خَيْرًا مِنْهَا، فَأْتِ الَّذِي هُوَ خَيْرٌ وَكَفِّرْ يَمِينَكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ سَمِعْتُ أَحْمَدَ يُرَخِّصُ فِيهَا الْكَفَّارَةَ قَبْلَ الْحِنْثِ ‏.‏\hadithno{3277}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6722) Sahih Muslim (1652)}\hadithtrans{Narrated 'Abd al-Rahman b. Samurah: The Prophet (ﷺ) said to me: 'Abd al-Rahman b. Samurah, when you swear an oath and consider something else to be better than it, do the thing that is beter and make atonement for your oath. Abu Dawud said: I heard Ahmad (b. Hanbal) permitting to make atonement before breaking the oath}}
\hadithdefcmd{abudawud}{3278}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، نَحْوَهُ قَالَ ‏:‏ ‏ "‏ فَكَفِّرْ عَنْ يَمِينِكَ، ثُمَّ ائْتِ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ أَحَادِيثُ أَبِي مُوسَى الأَشْعَرِيِّ وَعَدِيِّ بْنِ حَاتِمٍ وَأَبِي هُرَيْرَةَ فِي هَذَا الْحَدِيثِ رُوِيَ عَنْ كُلِّ وَاحِدٍ مِنْهُمْ فِي بَعْضِ الرِّوَايَةِ الْحِنْثُ قَبْلَ الْكَفَّارَةِ وَفِي بَعْضِ الرِّوَايَةِ الْكَفَّارَةُ قَبْلَ الْحِنْثِ ‏.‏\hadithno{3278}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1652)}\hadithtrans{A similar tradition has been transmitted by 'Abd al-Rahman b. Samurah through a different chain if narrators. This version has:"Make atonement for your oath and then do the thing that is better." Abu Dawud said: The version of this tradition transmitted by Abu Musa al-Ash'ari, 'Adi b. Hatim and Abu Hurairah are variant. Some of them indicate breaking the oath before making atonement, and other making atonement before breaking the oath}}
\hadithdefcmd{abudawud}{3279}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، قَالَ قَرَأْتُ عَلَى أَنَسِ بْنِ عِيَاضٍ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ حَرْمَلَةَ، عَنْ أُمِّ حَبِيبٍ بِنْتِ ذُؤَيْبِ بْنِ قَيْسٍ الْمُزَنِيَّةِ، - وَكَانَتْ تَحْتَ رَجُلٍ مِنْهُمْ مِنْ أَسْلَمَ ثُمَّ كَانَتْ تَحْتَ ابْنِ أَخٍ لِصَفِيَّةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَ ابْنُ حَرْمَلَةَ ‏:‏ فَوَهَبَتْ لَنَا أُمُّ حَبِيبٍ صَاعًا - حَدَّثَتْنَا عَنِ ابْنِ أَخِي صَفِيَّةَ عَنْ صَفِيَّةَ أَنَّهُ صَاعُ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَنَسٌ ‏:‏ فَجَرَّبْتُهُ، أَوْ قَالَ فَحَزَرْتُهُ فَوَجَدْتُهُ مُدَّيْنِ وَنِصْفًا بِمُدِّ هِشَامٍ ‏.‏\hadithno{3279}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Safiyyah bint Huyayy: Ibn Harmalah said: Umm Habib gave us a sa' and told us narration from the nephew of Safiyyah on the authority of Safiyyah that it was the sa' of the Prophet (ﷺ). Anas ibn Ayyad said: I tested it and found its capacity two and half mudd according to the mudd of Hisham}}
\hadithdefcmd{abudawud}{3280}{حَدَّثَنَا مُحَمَّدُ بْنُ مُحَمَّدِ بْنِ خَلاَّدٍ أَبُو عُمَرَ، قَالَ ‏:‏ كَانَ عِنْدَنَا مَكُّوكٌ يُقَالُ لَهُ مَكُّوكُ خَالِدٍ وَكَانَ كَيْلَجَتَيْنِ بِكَيْلَجَةِ هَارُونَ، قَالَ مُحَمَّدٌ ‏:‏ صَاعُ خَالِدٍ صَاعُ هِشَامٍ يَعْنِي ابْنَ عَبْدِ الْمَلِكِ ‏.‏\hadithno{3280}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Muhammad b. Muhmmad b. Khattab Abu 'Umar :We had a makkuk which was called Makkuk Khalid. Its capacity was two measurements according to the measurements of Harun. The narrator said: The sa' of Khalid was the sa' of Hisham b. 'Abd al-Malik}}
\hadithdefcmd{abudawud}{3281}{حَدَّثَنَا مُحَمَّدُ بْنُ مُحَمَّدِ بْنِ خَلاَّدٍ أَبُو عُمَرَ، حَدَّثَنَا مُسَدَّدٌ، عَنْ أُمَيَّةَ بْنِ خَالِدٍ، قَالَ ‏:‏ لَمَّا وُلِّيَ خَالِدٌ الْقَسْرِيُّ أَضْعَفَ الصَّاعَ فَصَارَ الصَّاعُ سِتَّةَ عَشَرَ رَطْلاً ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ مُحَمَّدُ بْنُ مُحَمَّدِ بْنِ خَلاَّدٍ قَتَلَهُ الزِّنْجُ صَبْرًا، فَقَالَ بِيَدِهِ هَكَذَا وَمَدَّ أَبُو دَاوُدَ يَدَهُ وَجَعَلَ بُطُونَ كَفَّيْهِ إِلَى الأَرْضِ، قَالَ ‏:‏ وَرَأَيْتُهُ فِي النَّوْمِ فَقُلْتُ ‏:‏ مَا فَعَلَ اللَّهُ بِكَ قَالَ ‏:‏ أَدْخَلَنِي الْجَنَّةَ ‏.‏ فَقُلْتُ ‏:‏ فَلَمْ يَضُرَّكَ الْوَقْفُ ‏.‏\hadithno{3281}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umayyah b. Khalid: When Khalid al-Qasri was made ruler (of Hijaz and Kufah), he doubled the measure of sa'. The sa' then measured sixteen rotls. Abu Dawud said: Muhammad b. Muhammad b. Khattab was slain by Negroes in confinement. He said while signing with his hand: "in this way". Abu Dawud extended his hand and turned his palms towards earth and said: I saw him in the dream and asked him: How did Allah deal with you ? He replied: He admitted to Paradise. I said: Your detention did not harm you}}
\hadithdefcmd{abudawud}{3282}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ الْحَجَّاجِ الصَّوَّافِ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ مُعَاوِيَةَ بْنِ الْحَكَمِ السُّلَمِيِّ، قَالَ قُلْتُ ‏:‏ يَا رَسُولَ اللَّهِ جَارِيَةٌ لِي صَكَكْتُهَا صَكَّةً ‏.‏ فَعَظَّمَ ذَلِكَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ أَفَلاَ أُعْتِقُهَا قَالَ ‏:‏ ‏"‏ ائْتِنِي بِهَا ‏"‏ ‏.‏ قَالَ ‏:‏ فَجِئْتُ بِهَا قَالَ ‏:‏ ‏"‏ أَيْنَ اللَّهُ ‏"‏ ‏.‏ قَالَتْ ‏:‏ فِي السَّمَاءِ ‏.‏ قَالَ ‏:‏ ‏"‏ مَنْ أَنَا ‏"‏ ‏.‏ قَالَتْ ‏:‏ أَنْتَ رَسُولُ اللَّهِ ‏.‏ قَالَ ‏:‏ ‏"‏ أَعْتِقْهَا فَإِنَّهَا مُؤْمِنَةٌ ‏"‏ ‏.‏\hadithno{3282}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (537)}\hadithtrans{Narrated Mu'awiyah b. al-Hakam al-Sulami:I said: Messenger of Allah, I have a slave girl whom I slapped. This grieved the Messenger of Allah (ﷺ). I said to him: Should I not emancipate her? He said: Bring her to me. He said: Then I brought her. He asked: Where is Allah ? She replied: In the heaven. He said: Who am I ? She replied: You are the Messenger of Allah. He said: Emancipate her, she is a believer}}
\hadithdefcmd{abudawud}{3283}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنِ الشَّرِيدِ، ‏:‏ أَنَّ أُمَّهُ، أَوْصَتْهُ أَنْ يُعْتِقَ، عَنْهَا رَقَبَةً مُؤْمِنَةً فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏:‏ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي أَوْصَتْ أَنْ أُعْتِقَ عَنْهَا رَقَبَةً مُؤْمِنَةً وَعِنْدِي جَارِيَةٌ سَوْدَاءُ نُوبِيَّةٌ فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ خَالِدُ بْنُ عَبْدِ اللَّهِ أَرْسَلَهُ لَمْ يَذْكُرِ الشَّرِيدَ ‏.‏\hadithno{3283}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ash-Sharid ibn Suwayd ath-Thaqafi: Sharid's mother left a will to emancipate a believing slave on her behalf. So he came to the Prophet (ﷺ) and said: Messenger of Allah, my mother left a will that I should emancipate a believing slave for her, and I have a black Nubian slave-girl. He mentioned a tradition about the test of the girl. Abu Dawud said: Khalid b. 'Abd Allah narrated this tradition direct from the Prophet (ﷺ). He did not mention the name of al-Sharid}}
\hadithdefcmd{abudawud}{3284}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ الْجُوزَجَانِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَخْبَرَنِي الْمَسْعُودِيُّ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، ‏:‏ أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم بِجَارِيَةٍ سَوْدَاءَ فَقَالَ ‏:‏ يَا رَسُولَ اللَّهِ إِنَّ عَلَىَّ رَقَبَةً مُؤْمِنَةً ‏.‏ فَقَالَ لَهَا ‏:‏ ‏"‏ أَيْنَ اللَّهُ ‏"‏ ‏.‏ فَأَشَارَتْ إِلَى السَّمَاءِ بِأُصْبُعِهَا ‏.‏ فَقَالَ لَهَا ‏:‏ ‏"‏ فَمَنْ أَنَا ‏"‏ ‏.‏ فَأَشَارَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم وَإِلَى السَّمَاءِ، يَعْنِي أَنْتَ رَسُولُ اللَّهِ ‏.‏ فَقَالَ ‏:‏ ‏"‏ أَعْتِقْهَا فَإِنَّهَا مُؤْمِنَةٌ ‏"‏ ‏.‏\hadithno{3284}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:A man brought the Prophet (ﷺ) a black slave girl. He said: Messenger of Allah, emancipation of believing slave is due to me. He asked her: Where is Allah ? She pointed to the heaven with her finger. He then asked her: Who am I ? She pointed to the Prophet (ﷺ) and to the heaven, that is to say: You are the Messenger of Allah. He then said: Set her free, she is a believer}}
\hadithdefcmd{abudawud}{3285}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا شَرِيكٌ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏"‏ وَاللَّهِ لأَغْزُوَنَّ قُرَيْشًا، وَاللَّهِ لأَغْزُوَنَّ قُرَيْشًا، وَاللَّهِ لأَغْزُوَنَّ قُرَيْشًا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏:‏ ‏"‏ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ وَقَدْ أَسْنَدَ هَذَا الْحَدِيثَ غَيْرُ وَاحِدٍ عَنْ شَرِيكٍ عَنْ سِمَاكٍ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ أَسْنَدَهُ عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَالَ الْوَلِيدُ بْنُ مُسْلِمٍ عَنْ شَرِيكٍ ‏:‏ ثُمَّ لَمْ يَغْزُهُمْ ‏.‏\hadithno{3285}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ikrimah ibn AbuJahl: The Prophet (ﷺ) said: I swear by Allah, I shall fight against the Quraysh; I swear by Allah, I shall fight against the Quraysh; I swear by Allah, I shall fight against the Quraysh. He then said: "If Allah wills." Abu Dawud said: A number of persons have narrated this tradition from Sharik, from Simak, from 'Ikrimah, from Ibn 'Abbas who reported from the Prophet (ﷺ): "But he did not fight against them}}
\hadithdefcmd{abudawud}{3286}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، يَرْفَعُهُ قَالَ ‏:‏ ‏"‏ وَاللَّهِ لأَغْزُوَنَّ قُرَيْشًا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏:‏ ‏"‏ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏:‏ ‏"‏ وَاللَّهِ لأَغْزُوَنَّ قُرَيْشًا إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏:‏ ‏"‏ وَاللَّهِ لأَغْزُوَنَّ قُرَيْشًا ‏"‏ ‏.‏ ثُمَّ سَكَتَ ثُمَّ قَالَ ‏:‏ ‏"‏ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ زَادَ فِيهِ الْوَلِيدُ بْنُ مُسْلِمٍ عَنْ شَرِيكٍ قَالَ ‏:‏ ثُمَّ لَمْ يَغْزُهُمْ ‏.‏\hadithno{3286}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ikrimah: The Prophet (ﷺ) as saying: I swear by Allah, I shall fight against the Quraish. The then said: If Allah wills. He again said: I swear by Allah, I shall fight against the Quraish if Allah wills. He again said: I swear by Allah, I shall fight against the Quraish. He then kept silence. Then he said: If Allah wills. Abu Dawud said: Al-Walid b. Muslim said on the authority of Sharik: He then said: But he did not fight against them}}
\hadithdefcmd{abudawud}{3287}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، قَالَ عُثْمَانُ الْهَمْدَانِيُّ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ ‏:‏ أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنِ النَّذْرِ ثُمَّ اتَّفَقَا وَيَقُولُ ‏:‏ ‏"‏ لاَ يَرُدُّ شَيْئًا، وَإِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ ‏"‏ ‏.‏ قَالَ مُسَدَّدٌ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ النَّذْرُ لاَ يَرُدُّ شَيْئًا ‏"‏ ‏.‏\hadithno{3287}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6608) Sahih Muslim (1639)}\hadithtrans{Narrated 'Abd Allah b. 'Umar: The Messenger of Allah (ﷺ) forbade to make a vow. He said: It has not effect against fate, it is only from the miserly that it is means by which something is extracted. Musaddad said: The Messenger of Allah (ﷺ) said: A vow does not avert anything (i.e. has no effect against fate)}}
\hadithdefcmd{abudawud}{3288}{حَدَّثَنَا أَبُو دَاوُدَ، قَالَ قُرِئَ عَلَى الْحَارِثِ بْنِ مِسْكِينٍ وَأَنَا شَاهِدٌ، أَخْبَرَكُمُ ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ لاَ يَأْتِي ابْنَ آدَمَ النَّذْرُ الْقَدَرَ بِشَىْءٍ لَمْ أَكُنْ قَدَّرْتُهُ لَهُ، وَلَكِنْ يُلْقِيهِ النَّذْرُ الْقَدَرَ قَدَّرْتُهُ يُسْتَخْرَجُ مِنَ الْبَخِيلِ يُؤْتَى عَلَيْهِ مَا لَمْ يَكُنْ يُؤْتَى مِنْ قَبْلُ ‏"‏ ‏.‏\hadithno{3288}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6694) Sahih Muslim (1640)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: A vow does not provide for the son of Adam anything which I did not decree for him, but a vow draws it. A Divine decree is one which I have destined, it is extracted from a miser. He is given what he was not given before}}
\hadithdefcmd{abudawud}{3289}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ طَلْحَةَ بْنِ عَبْدِ الْمَلِكِ الأَيْلِيِّ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ مَنْ نَذَرَ أَنْ يُطِيعَ اللَّهَ فَلْيُطِعْهُ، وَمَنْ نَذَرَ أَنْ يَعْصِيَ اللَّهَ فَلاَ يَعْصِهِ ‏"‏ ‏.‏\hadithno{3289}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6696، 6700)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) as saying: If anyone vows to obey Allah, let him obey Him, but if anyone vows to disobey Him, let him not disobey Him}}
\hadithdefcmd{abudawud}{3290}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ، وَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏\hadithno{3290}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) as saying: No vow must be taken to do an act of disobedience, and the atonement for it is the same as for an oath}}
\hadithdefcmd{abudawud}{3291}{حَدَّثَنَا ابْنُ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، بِمَعْنَاهُ وَإِسْنَادِهِ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ بْنَ شَبُّويَةَ، يَقُولُ قَالَ ابْنُ الْمُبَارَكِ - يَعْنِي فِي هَذَا الْحَدِيثِ - حَدَّثَ أَبُو سَلَمَةَ، فَدَلَّ ذَلِكَ عَلَى أَنَّ الزُّهْرِيَّ، لَمْ يَسْمَعْهُ مِنْ أَبِي سَلَمَةَ، وَقَالَ أَحْمَدُ بْنُ مُحَمَّدٍ ‏:‏ وَتَصْدِيقُ ذَلِكَ مَا حَدَّثَنَا أَيُّوبُ - يَعْنِي ابْنَ سُلَيْمَانَ - قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يَقُولُ ‏:‏ أَفْسَدُوا عَلَيْنَا هَذَا الْحَدِيثَ ‏.‏ قِيلَ لَهُ ‏:‏ وَصَحَّ إِفْسَادُهُ عِنْدَكَ وَهَلْ رَوَاهُ غَيْرُ ابْنِ أَبِي أُوَيْسٍ قَالَ ‏:‏ أَيُّوبُ كَانَ أَمْثَلَ مِنْهُ ‏.‏ يَعْنِي أَيُّوبَ بْنَ سُلَيْمَانَ بْنِ بِلاَلٍ، وَقَدْ رَوَاهُ أَيُّوبُ ‏.‏\hadithno{3291}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by al-Zuhri through a different chain of narrators to the same effect. Abu Dawud said:I heard Ahmad b. Shabbuyah say: Ibn al-Mubarak said about this tradition that Abu Salamah had transmitted it. This indicates that al-Zuhri did not hear it from Abu Salamah. Ahmad b. Muhammad said: This is verified by what Ayyub b. Sulaiman narrated to us. Abu Dawud said: I heard Ahmad b. Hanbal say: I have corrupted this tradition for us. He was asked: Do you think that it is correct that this tradition has been corrupted? Has any person other than Ibn Abi Uwais transmitted it ? He replied: Ayyub was similar to him in respect of reliability, and Ayyub transmitted it}}
\hadithdefcmd{abudawud}{3292}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنَا أَيُّوبُ بْنُ سُلَيْمَانَ، عَنْ أَبِي بَكْرِ بْنِ أَبِي أُوَيْسٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنِ ابْنِ أَبِي عَتِيقٍ، وَمُوسَى بْنِ عُقْبَةَ، عَنِ ابْنِ شِهَابٍ، عَنْ سُلَيْمَانَ بْنِ أَرْقَمَ، أَنَّ يَحْيَى بْنَ أَبِي كَثِيرٍ، أَخْبَرَهُ عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، رَضِيَ اللَّهُ عَنْهَا، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ، وَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏ قَالَ أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ ‏:‏ إِنَّمَا الْحَدِيثُ حَدِيثُ عَلِيِّ بْنِ الْمُبَارَكِ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ مُحَمَّدِ بْنِ الزُّبَيْرِ عَنْ أَبِيهِ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ أَرَادَ أَنَّ سُلَيْمَانَ بْنَ أَرْقَمَ وَهِمَ فِيهِ وَحَمَلَهُ عَنْهُ الزُّهْرِيُّ وَأَرْسَلَهُ عَنْ أَبِي سَلَمَةَ عَنْ عَائِشَةَ رَحِمَهَا اللَّهُ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ رَوَى بَقِيَّةُ عَنِ الأَوْزَاعِيِّ عَنْ يَحْيَى عَنْ مُحَمَّدِ بْنِ الزُّبَيْرِ بِإِسْنَادِ عَلِيِّ بْنِ الْمُبَارَكِ مِثْلَهُ ‏.‏\hadithno{3292}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) as saying: No vow must be taken to do an act of disobedience, and the atonement for it is the same as for an oath. Ahmad b. Muhammad al-Marwazi said: The correct chain of this tradition is: 'Ali b. al-Mubarak, from Yahya b. Abi Kathir, from Muhammad b. al-Zubair, from his father, on the authority of 'Imran b. Husain from the Prophet (ﷺ) Abu Dawud said: By this he (al-Marwazi) means that the narrator Sulaiman b. Arqam had some misunderstanding about this tradition. Al-Zuhri narrated it from him and then transmitted it (omitting his name) from Abu Salamah on the authority of 'Aishah. Abu Dawud said: Baqiyyah has transmitted it from al-Auza'i from Yahya, from Muhammad b. al-Zubair with a similar chain of Ibn al-Mubarak}}
\hadithdefcmd{abudawud}{3293}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، قَالَ أَخْبَرَنِي يَحْيَى بْنُ سَعِيدٍ الأَنْصَارِيُّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ زَحْرٍ، أَنَّ أَبَا سَعِيدٍ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ مَالِكٍ أَخْبَرَهُ أَنَّ عُقْبَةَ بْنَ عَامِرٍ أَخْبَرَهُ ‏:‏ أَنَّهُ، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ أُخْتٍ لَهُ نَذَرَتْ أَنْ تَحُجَّ حَافِيَةً غَيْرَ مُخْتَمِرَةٍ فَقَالَ ‏:‏ ‏ "‏ مُرُوهَا فَلْتَخْتَمِرْ وَلْتَرْكَبْ، وَلْتَصُمْ ثَلاَثَةَ أَيَّامٍ ‏"‏ ‏.‏\hadithno{3293}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Uqbah ibn Amir: Uqbah consulted the Prophet (ﷺ) about his sister who took a vow to perform hajj barefooted and bareheaded. So he said: Command her to cover her head and to ride, and to fast three days}}
\hadithdefcmd{abudawud}{3294}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ كَتَبَ إِلَىَّ يَحْيَى بْنُ سَعِيدٍ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ زَحْرٍ، مَوْلَى لِبَنِي ضَمْرَةَ - وَكَانَ أَيَّمَا رَجُلٍ - أَنَّ أَبَا سَعِيدٍ الرُّعَيْنِيَّ أَخْبَرَهُ بِإِسْنَادِ يَحْيَى وَمَعْنَاهُ ‏.‏\hadithno{3294}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Sa'id al-Ru'aini with the same chain as narrated by Yahya (b. Sa'id) and to the same effect}}
\hadithdefcmd{abudawud}{3295}{حَدَّثَنَا حَجَّاجُ بْنُ أَبِي يَعْقُوبَ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا شَرِيكٌ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى آلِ طَلْحَةَ عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏:‏ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏:‏ يَا رَسُولَ اللَّهِ إِنَّ أُخْتِي نَذَرَتْ - يَعْنِي - أَنْ تَحُجَّ مَاشِيَةً ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏ "‏ إِنَّ اللَّهَ لاَ يَصْنَعُ بِشَقَاءِ أُخْتِكَ شَيْئًا، فَلْتَحُجَّ رَاكِبَةً وَلْتُكَفِّرْ عَنْ يَمِينِهَا ‏"‏ ‏.‏\hadithno{3295}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: A man came to Prophet (ﷺ) and said: Messenger of Allah, my sister has taken a vow to perform hajj on foot. The Prophet (ﷺ) said: Allah gets no good from the affliction your sister imposed on herself, so let her perform hajj riding and make atonement for her oath}}
\hadithdefcmd{abudawud}{3296}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏:‏ أَنَّ أُخْتَ، عُقْبَةَ بْنِ عَامِرٍ نَذَرَتْ أَنْ تَمْشِيَ، إِلَى الْبَيْتِ، فَأَمَرَهَا النَّبِيُّ صلى الله عليه وسلم أَنْ تَرْكَبَ وَتُهْدِيَ هَدْيًا ‏.‏\hadithno{3296}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas:That the sister of 'Uqbah b. 'Amir took vow to walk on foot to the Ka'bah. Thereupon the Prophet (ﷺ) ordered her to ride and slaughter a sacrificial animal}}
\hadithdefcmd{abudawud}{3297}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏:‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا بَلَغَهُ أَنَّ أُخْتَ عُقْبَةَ بْنِ عَامِرٍ نَذَرَتْ أَنْ تَحُجَّ مَاشِيَةً قَالَ ‏:‏ ‏ "‏ إِنَّ اللَّهَ لَغَنِيٌّ عَنْ نَذْرِهَا، مُرْهَا فَلْتَرْكَبْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ رَوَاهُ سَعِيدُ بْنُ أَبِي عَرُوبَةَ نَحْوَهُ وَخَالِدٌ عَنْ عِكْرِمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{3297}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas: That when the Prophet (ﷺ) was informed that the sister of 'Uqbah b. 'Amir had taken a vow to perform Hajj on foot, he said: Allah is not in need of her vow. So ask her to ride. Abu Dawud said: Sa'ib b. 'Arubah has transmitted a similar tradition. Khalid has also transmitted a similar tradition on the authority of 'Ikrimah from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3298}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، أَنَّ أُخْتَ، عُقْبَةَ بْنِ عَامِرٍ بِمَعْنَى هِشَامٍ وَلَمْ يَذْكُرِ الْهَدْىَ وَقَالَ فِيهِ ‏:‏ ‏ "‏ مُرْ أُخْتَكَ فَلْتَرْكَبْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ رَوَاهُ خَالِدٌ عَنْ عِكْرِمَةَ بِمَعْنَى هِشَامٍ ‏.‏\hadithno{3298}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Ikrimah: The tradition about the sister of 'Uqbah b. 'Amir as narrated by Hisham, but he made no mention of the sacrificial animal. In his version he said: Ask your sister to ride. Abu Dawud said: Khalid narrated it from 'Ikrimah to the same effect as narrated by Hisham}}
\hadithdefcmd{abudawud}{3299}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، أَنَّ يَزِيدَ بْنَ أَبِي حَبِيبٍ، أَخْبَرَهُ أَنَّ أَبَا الْخَيْرِ حَدَّثَهُ عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ ‏:‏ نَذَرَتْ أُخْتِي أَنْ تَمْشِيَ، إِلَى بَيْتِ اللَّهِ، فَأَمَرَتْنِي أَنْ أَسْتَفْتِيَ لَهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَاسْتَفْتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏:‏ ‏ "‏ لِتَمْشِ وَلْتَرْكَبْ ‏"‏ ‏.‏\hadithno{3299}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1866) Sahih Muslim (1644)}\hadithtrans{Narrated 'Uqbah bin 'Amir al-Juhani:My sister took a vow to walk on foot to the House of Allah (i.e. Ka'bah). She asked me to consult the Prophet (ﷺ) about her. So I consulted the Prophet (ﷺ). He said: Let her walk and ride}}
\hadithdefcmd{abudawud}{3300}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏:‏ بَيْنَمَا النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ إِذَا هُوَ بِرَجُلٍ قَائِمٍ فِي الشَّمْسِ فَسَأَلَ عَنْهُ قَالُوا ‏:‏ هَذَا أَبُو إِسْرَائِيلَ نَذَرَ أَنْ يَقُومَ وَلاَ يَقْعُدَ، وَلاَ يَسْتَظِلَّ وَلاَ يَتَكَلَّمَ وَيَصُومَ ‏.‏ قَالَ ‏:‏ ‏ "‏ مُرُوهُ فَلْيَتَكَلَّمْ وَلْيَسْتَظِلَّ وَلْيَقْعُدْ، وَلْيُتِمَّ صَوْمَهُ ‏"‏ ‏.‏\hadithno{3300}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6704)}\hadithtrans{Narrated Ibn 'Abbas:While the Prophet (ﷺ) was preaching a man was standing in the sun. He asked about him. They said: He is Abu Isra'il who has taken a vow to stand and not to sit, or go into shade, or speak, but to fast. Thereupon he said: Command him to speak, to go into the shade, sit and complete his fast}}
\hadithdefcmd{abudawud}{3301}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، ‏:‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يُهَادَى بَيْنَ ابْنَيْهِ فَسَأَلَ عَنْهُ فَقَالُوا ‏:‏ نَذَرَ أَنْ يَمْشِيَ ‏.‏ فَقَالَ ‏:‏ ‏ "‏ إِنَّ اللَّهَ لَغَنِيٌّ عَنْ تَعْذِيبِ هَذَا نَفْسَهُ ‏"‏ ‏.‏ وَأَمَرَهُ أَنْ يَرْكَبَ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ رَوَاهُ عَمْرُو بْنُ أَبِي عَمْرٍو عَنِ الأَعْرَجِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{3301}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6701) Sahih Muslim (1642)}\hadithtrans{Narrated Anas b. Malik : The Messenger of Allah (ﷺ) saw a man that he was supported between his sons. He asked about him, and (the people) said: He has taken a vow to walk (on foot). Thereupon he said: Allah has no need that this man should punish himself, and he ordered him to ride. Abu Dawud said: 'Amr b. Abi 'Amir has also narrated a similar tradition from al-A'raj on the authority of Abu Hurairah from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3302}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي الأَحْوَلُ، أَنَّ طَاوُسًا، أَخْبَرَهُ عَنِ ابْنِ عَبَّاسٍ، ‏:‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ وَهُوَ يَطُوفُ بِالْكَعْبَةِ بِإِنْسَانٍ يَقُودُهُ بِخِزَامَةٍ فِي أَنْفِهِ، فَقَطَعَهَا النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ وَأَمَرَهُ أَنْ يَقُودَهُ بِيَدِهِ ‏.‏\hadithno{3302}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1620)}\hadithtrans{Narrated Ibn 'Abbas:The Prophet (ﷺ) while going round the Ka'bah passed a man who was led with a ring of bridle in his nose. The Prophet (ﷺ) cut it off with his hand and ordered to lead him by catching his hand}}
\hadithdefcmd{abudawud}{3303}{حَدَّثَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ السُّلَمِيُّ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ، - يَعْنِي ابْنَ طَهْمَانَ - عَنْ مَطَرٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏:‏ أَنَّ أُخْتَ، عُقْبَةَ بْنِ عَامِرٍ نَذَرَتْ أَنْ تَحُجَّ، مَاشِيَةً وَأَنَّهَا لاَ تُطِيقُ ذَلِكَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏ "‏ إِنَّ اللَّهَ لَغَنِيٌّ عَنْ مَشْىِ أُخْتِكَ، فَلْتَرْكَبْ وَلْتُهْدِ بَدَنَةً ‏"‏ ‏.‏\hadithno{3303}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The sister of Uqbah ibn Amir took a vow that she would perform hajj on foot, and she was unable to do so. The Prophet (ﷺ) said: Allah is not in need of the walking of your sister. She must ride and offer a sacrificial camel}}
\hadithdefcmd{abudawud}{3304}{حَدَّثَنَا شُعَيْبُ بْنُ أَيُّوبَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ سُفْيَانَ، عَنْ أَبِيهِ، عَنْ عِكْرِمَةَ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، أَنَّهُ قَالَ لِلنَّبِيِّ صلى الله عليه وسلم ‏:‏ إِنَّ أُخْتِي نَذَرَتْ أَنْ تَمْشِيَ إِلَى الْبَيْتِ ‏.‏ فَقَالَ ‏:‏ ‏ "‏ إِنَّ اللَّهَ لاَ يَصْنَعُ بِمَشْىِ أُخْتِكَ إِلَى الْبَيْتِ شَيْئًا ‏"‏ ‏.‏\hadithno{3304}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Uqbah ibn Amir al-Juhani: Uqbah said to the Prophet (ﷺ): My sister has taken a vow that she will walk to the House of Allah (the Ka'bah). Thereupon he said: Allah will not do anything of the walking of your sister to the House of Allah (i.e. the Ka'bah)}}
\hadithdefcmd{abudawud}{3305}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ أَخْبَرَنَا حَبِيبٌ الْمُعَلِّمُ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، ‏:‏ أَنَّ رَجُلاً، قَامَ يَوْمَ الْفَتْحِ فَقَالَ ‏:‏ يَا رَسُولَ اللَّهِ إِنِّي نَذَرْتُ لِلَّهِ إِنْ فَتَحَ اللَّهُ عَلَيْكَ مَكَّةَ أَنْ أُصَلِّيَ فِي بَيْتِ الْمَقْدِسِ رَكْعَتَيْنِ ‏.‏ قَالَ ‏:‏ ‏"‏ صَلِّ هَا هُنَا ‏"‏ ثُمَّ أَعَادَ عَلَيْهِ فَقَالَ ‏:‏ ‏"‏ صَلِّ هَا هُنَا ‏"‏ ثُمَّ أَعَادَ عَلَيْهِ فَقَالَ ‏:‏ ‏"‏ شَأْنَكَ إِذًا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ رُوِيَ نَحْوُهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3305}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: A man stood on the day of Conquest (of Mecca) and said: Messenger of Allah, I have vowed to Allah that if He grants conquest of Mecca at your hands, I shall pray two rak'ahs in Jerusalem. He replied: Pray here. He repeated (his statement) to him and he said: Pray here. He again repeated (his statement) to him. He (the Prophet) replied: Pursue your own course, then. Abu Dawud said: A similar tradition has been narrated by 'Abd al-Rahman b. 'Awf from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3306}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، ح وَحَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، - الْمَعْنَى - قَالَ حَدَّثَنَا رَوْحٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي يُوسُفُ بْنُ الْحَكَمِ بْنِ أَبِي سُفْيَانَ، أَنَّهُ سَمِعَ حَفْصَ بْنَ عُمَرَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، وَعَمْرًا، وَقَالَ، عَبَّاسٌ ‏:‏ ابْنَ حَنَّةَ أَخْبَرَاهُ عَنْ عُمَرَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ رِجَالٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْخَبَرِ ‏.‏ زَادَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَالَّذِي بَعَثَ مُحَمَّدًا بِالْحَقِّ لَوْ صَلَّيْتَ هَا هُنَا لأَجْزَأَ عَنْكَ صَلاَةً فِي بَيْتِ الْمَقْدِسِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ رَوَاهُ الأَنْصَارِيُّ عَنِ ابْنِ جُرَيْجٍ فَقَالَ جَعْفَرُ بْنُ عَمْرٍو، وَقَالَ عَمْرُو بْنُ حَيَّةَ وَقَالَ أَخْبَرَاهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَعَنْ رِجَالٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3306}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above (No.3299) has also been transmitted by Umar ibn Abd al-Rahman ibn Awf on the authority of his father and the Companions of the Prophet (ﷺ). This version has:"The Prophet (ﷺ) said: By Him Who sent Muhammad with truth, if you prayed here, this would be sufficient for you like the prayer in Jerusalem." Abu Dawud said: This tradition has also been transmitted by al-Ansari, from Ibn-Juraij. He said: Ja'far b. 'Umar and 'Amr b. Hayyah. He said: They transmitted from 'Abd al-Rahman b. 'Awf and from the Companions of the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3307}{حَدَّثَنَا الْقَعْنَبِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، ‏:‏ أَنَّ سَعْدَ بْنَ عُبَادَةَ، اسْتَفْتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏:‏ إِنَّ أُمِّي مَاتَتْ وَعَلَيْهَا نَذْرٌ لَمْ تَقْضِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْضِهِ عَنْهَا ‏"‏ ‏.‏\hadithno{3307}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2761) Sahih Muslim (1638)}\hadithtrans{Narrated Ibn 'Abbas:Sa'd b. 'Ubadah asked the Messenger of Allah (ﷺ): My Mother has died and she could not fulfill her vow which she had taken. The Messenger of Allah (ﷺ) said: Fulfill it on her behalf}}
\hadithdefcmd{abudawud}{3308}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، ‏:‏ أَنَّ امْرَأَةً، رَكِبَتِ الْبَحْرَ فَنَذَرَتْ إِنْ نَجَّاهَا اللَّهُ أَنْ تَصُومَ شَهْرًا، فَنَجَّاهَا اللَّهُ فَلَمْ تَصُمْ حَتَّى مَاتَتْ، فَجَاءَتِ ابْنَتُهَا أَوْ أُخْتُهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَهَا أَنْ تَصُومَ عَنْهَا ‏.‏\hadithno{3308}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: A woman made a voyage and vowed that she would fast one month if Allah made her reach her destination with peace and security. Allah made her reach her destination with security but she died before she could fast. Her daughter or sister (the narrator doubted) came to the Messenger of Allah (ﷺ). So he commanded to fast on her behalf}}
\hadithdefcmd{abudawud}{3309}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، بُرَيْدَةَ ‏:‏ أَنَّ امْرَأَةً، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ ‏:‏ كُنْتُ تَصَدَّقْتُ عَلَى أُمِّي بِوَلِيدَةٍ، وَإِنَّهَا مَاتَتْ وَتَرَكَتْ تِلْكَ الْوَلِيدَةَ ‏.‏ قَالَ ‏:‏ ‏ "‏ قَدْ وَجَبَ أَجْرُكِ، وَرَجَعَتْ إِلَيْكِ فِي الْمِيرَاثِ ‏"‏ ‏.‏ قَالَتْ ‏:‏ وَإِنَّهَا مَاتَتْ وَعَلَيْهَا صَوْمُ شَهْرٍ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ عَمْرٍو ‏.‏\hadithno{3309}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1149)}\hadithtrans{Narrated Buraidah:A woman came to the Prophet (ﷺ) and said: I gave a slave girl to my mother, but she died and left the salve-girl. He said: Your reward became certain for you, and she (the slave-girl) returned to you as inheritance. She said: She died and one month's fast was due from her. He (the narrator) then mentioned the tradition similar to the one mentioned by 'Amr b. 'Awn}}
\hadithdefcmd{abudawud}{3310}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، قَالَ سَمِعْتُ الأَعْمَشَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، - الْمَعْنَى - عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، ‏:‏ أَنَّ امْرَأَةً، جَاءَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ ‏:‏ إِنَّهُ كَانَ عَلَى أُمِّهَا صَوْمُ شَهْرٍ أَفَأَقْضِيهِ عَنْهَا فَقَالَ ‏:‏ ‏"‏ لَوْ كَانَ عَلَى أُمِّكِ دَيْنٌ أَكُنْتِ قَاضِيَتَهُ ‏"‏ ‏.‏ قَالَتْ ‏:‏ نَعَمْ ‏.‏ قَالَ ‏:‏ ‏"‏ فَدَيْنُ اللَّهِ أَحَقُّ أَنْ يُقْضَى ‏"‏ ‏.‏\hadithno{3310}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1953) Sahih Muslim (1148)}\hadithtrans{Narrated Ibn 'Abbas:A woman came to the Prophet (ﷺ) and said (to him) that one month's fast was due from her mother who had died. May I fulfill them on her behalf? He asked: Suppose some debt was due from your mother, would you pay it ? She replied: Yes. He said: So the debt due to Allah is the one which most deserves to be paid}}
\hadithdefcmd{abudawud}{3311}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ مَنْ مَاتَ وَعَلَيْهِ صِيَامٌ صَامَ عَنْهُ وَلِيُّهُ ‏"‏ ‏.‏\hadithno{3311}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1952) Sahih Muslim (1147)}\hadithtrans{Narrated 'Aishah:The Prophet (ﷺ) as saying: If anyone dies when some fast due from him has been unfulfilled, his heir must fast on his behalf}}
\hadithdefcmd{abudawud}{3312}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْحَارِثُ بْنُ عُبَيْدٍ أَبُو قُدَامَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، ‏:‏ أَنَّ امْرَأَةً، أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ ‏:‏ يَا رَسُولَ اللَّهِ إِنِّي نَذَرْتُ أَنْ أَضْرِبَ عَلَى رَأْسِكَ بِالدُّفِّ ‏.‏ قَالَ ‏:‏ ‏"‏ أَوْفِي بِنَذْرِكِ ‏"‏ ‏.‏ قَالَتْ ‏:‏ إِنِّي نَذَرْتُ أَنْ أَذْبَحَ بِمَكَانِ كَذَا وَكَذَا، مَكَانٌ كَانَ يَذْبَحُ فِيهِ أَهْلُ الْجَاهِلِيَّةِ ‏.‏ قَالَ ‏:‏ ‏"‏ لِصَنَمٍ ‏"‏ ‏.‏ قَالَتْ ‏:‏ لاَ ‏.‏ قَالَ ‏:‏ ‏"‏ لِوَثَنٍ ‏"‏ ‏.‏ قَالَتْ ‏:‏ لاَ ‏.‏ قَالَ ‏:‏ ‏"‏ أَوْفِي بِنَذْرِكِ ‏"‏ ‏.‏\hadithno{3312}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather said: A woman came to the Prophet (ﷺ) and said: Messenger of Allah, I have taken a vow to play the tambourine over you. He said: Fulfil your vow. She said: And I have taken a vow to perform a sacrifice in such a such a place, a place in which people had performed sacrifices in pre-Islamic times. He asked: For an Idol? She replied: No. He asked: For an image? She replied: No. He said: Fulfil your vow}}
\hadithdefcmd{abudawud}{3313}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو قِلاَبَةَ، قَالَ حَدَّثَنِي ثَابِتُ بْنُ الضَّحَّاكِ، قَالَ ‏:‏ نَذَرَ رَجُلٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنْ يَنْحَرَ إِبِلاً بِبُوَانَةَ، فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏:‏ إِنِّي نَذَرْتُ أَنْ أَنْحَرَ إِبِلاً بِبُوَانَةَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏"‏ هَلْ كَانَ فِيهَا وَثَنٌ مِنْ أَوْثَانِ الْجَاهِلِيَّةِ يُعْبَدُ ‏"‏ ‏.‏ قَالُوا ‏:‏ لاَ ‏.‏ قَالَ ‏:‏ ‏"‏ هَلْ كَانَ فِيهَا عِيدٌ مِنْ أَعْيَادِهِمْ ‏"‏ ‏.‏ قَالُوا ‏:‏ لاَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ أَوْفِ بِنَذْرِكَ، فَإِنَّهُ لاَ وَفَاءَ لِنَذْرٍ فِي مَعْصِيَةِ اللَّهِ وَلاَ فِيمَا لاَ يَمْلِكُ ابْنُ آدَمَ ‏"‏ ‏.‏\hadithno{3313}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Thabit ibn ad-Dahhak: In the time of the Prophet (ﷺ) a man took a vow to slaughter a camel at Buwanah. So he came to the Prophet (ﷺ) and said: I have taken a vow to sacrifice a camel at Buwanah. The Prophet (ﷺ) asked: Did the place contain any idol worshipped in pre-Islamic times? They (the people) said: No. He asked: Was any pre-Islamic festival observed there? They replied: No. The Prophet (ﷺ) said: Fulfil your vow, for a vow to do an act of disobedience to Allah must not be fulfilled, neither must one do something over which a human being has no control}}
\hadithdefcmd{abudawud}{3314}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ بْنِ مِقْسَمٍ الثَّقَفِيُّ، مِنْ أَهْلِ الطَّائِفِ قَالَ حَدَّثَتْنِي سَارَّةُ بِنْتُ مِقْسَمٍ الثَّقَفِيِّ، أَنَّهَا سَمِعَتْ مَيْمُونَةَ بِنْتَ كَرْدَمٍ، قَالَتْ ‏:‏ خَرَجْتُ مَعَ أَبِي فِي حَجَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَسَمِعْتُ النَّاسَ يَقُولُونَ ‏:‏ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَعَلْتُ أُبِدُّهُ بَصَرِي، فَدَنَا إِلَيْهِ أَبِي وَهُوَ عَلَى نَاقَةٍ لَهُ مَعَهُ دِرَّةٌ كَدِرَّةِ الْكُتَّابِ، فَسَمِعْتُ الأَعْرَابَ وَالنَّاسَ يَقُولُونَ ‏:‏ الطَّبْطَبِيَّةَ الطَّبْطَبِيَّةَ، فَدَنَا إِلَيْهِ أَبِي فَأَخَذَ بِقَدَمِهِ قَالَتْ ‏:‏ فَأَقَرَّ لَهُ وَوَقَفَ فَاسْتَمَعَ مِنْهُ فَقَالَ ‏:‏ يَا رَسُولَ اللَّهِ إِنِّي نَذَرْتُ إِنْ وُلِدَ لِي وَلَدٌ ذَكَرٌ أَنْ أَنْحَرَ عَلَى رَأْسِ بُوَانَةَ فِي عَقَبَةٍ مِنَ الثَّنَايَا عِدَّةً مِنَ الْغَنَمِ ‏.‏ قَالَ ‏:‏ لاَ أَعْلَمُ إِلاَّ أَنَّهَا قَالَتْ خَمْسِينَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏"‏ هَلْ بِهَا مِنَ الأَوْثَانِ شَىْءٌ ‏"‏ ‏.‏ قَالَ ‏:‏ لاَ ‏.‏ قَالَ ‏:‏ ‏"‏ فَأَوْفِ بِمَا نَذَرْتَ بِهِ لِلَّهِ ‏"‏ ‏.‏ قَالَتْ ‏:‏ فَجَمَعَهَا فَجَعَلَ يَذْبَحُهَا فَانْفَلَتَتْ مِنْهَا شَاةٌ فَطَلَبَهَا، وَهُوَ يَقُولُ ‏:‏ اللَّهُمَّ أَوْفِ عَنِّي نَذْرِي ‏.‏ فَظَفِرَهَا فَذَبَحَهَا ‏.‏\hadithno{3314}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Maymunah, daughter of Kardam: I went out with my father to see the hajj performed by the Messenger of Allah (ﷺ). I saw the Messenger of Allah (ﷺ). I fixed my eyes on him. My father came near him while he was riding his she-camel. He had a whip like the whip of scribes. I heard the bedouin and the people say: The whip, the whip. My father came near him and held his foot. She said: He admitted his Prophethood and stood and listened to him. He said: Messenger of Allah, I have made a vow that if a son is born to me, I shall slaughter a number of sheep at the end of Buwanah in the dale of hill. The narrator said: I do not know (for certain) that she said: Fifty (sheep). The Messenger of Allah (ﷺ) said: Does it contain any idol? He said: No. Then he said: Fulfil your vow that you have taken for Allah. He then gathered them (i.e. the sheep) and began to slaughter them. A sheep ran away from them. He searched for it saying: O Allah, fulfil my vow on my behalf. So he succeeded (in finding it) and slaughtered it}}
\hadithdefcmd{abudawud}{3315}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ مَيْمُونَةَ بِنْتِ كَرْدَمِ بْنِ سُفْيَانَ، عَنْ أَبِيهَا، نَحْوَهُ مُخْتَصَرٌ مِنْهُ شَىْءٌ قَالَ ‏:‏ ‏"‏ هَلْ بِهَا وَثَنٌ أَوْ عِيدٌ مِنْ أَعْيَادِ الْجَاهِلِيَّةِ ‏"‏ ‏.‏ قَالَ ‏:‏ لاَ ‏.‏ قُلْتُ ‏:‏ إِنَّ أُمِّي هَذِهِ عَلَيْهَا نَذْرٌ وَمَشْىٌ أَفَأَقْضِيهِ عَنْهَا وَرُبَّمَا قَالَ ابْنُ بَشَّارٍ ‏:‏ أَنَقْضِيهِ عَنْهَا قَالَ ‏:‏ ‏"‏ نَعَمْ ‏"‏ ‏.‏\hadithno{3315}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{A similar tradition has also been transmitted in brief by Maimunah daughter of Kardam son of Sufyan on the authority of her father through a different chain of narrators. This version adds:(The Prophet asked): Does it contain an idol or was a festival of pre-Islamic times celebrated there ? He replied: No. I said: This mother of mine has taken a vow and walking (is binding on her). May I fulfill it on her behalf ? Sometimes the narrator Bashshar said: May we fulfill in on her behalf ? He said: Yes}}
\hadithdefcmd{abudawud}{3316}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، ‏:‏ قَالَ كَانَتِ الْعَضْبَاءُ لِرَجُلٍ مِنْ بَنِي عَقِيلٍ وَكَانَتْ مِنْ سَوَابِقِ الْحَاجِّ قَالَ ‏:‏ فَأُسِرَ فَأَتَى النَّبِيَّ صلى الله عليه وسلم وَهُوَ فِي وَثَاقٍ وَالنَّبِيُّ صلى الله عليه وسلم عَلَى حِمَارٍ عَلَيْهِ قَطِيفَةٌ فَقَالَ ‏:‏ يَا مُحَمَّدُ عَلاَمَ تَأْخُذُنِي وَتَأْخُذُ سَابِقَةَ الْحَاجِّ قَالَ ‏:‏ ‏"‏ نَأْخُذُكَ بِجَرِيرَةِ حُلَفَائِكَ ثَقِيفٍ ‏"‏ ‏.‏ قَالَ ‏:‏ وَكَانَ ثَقِيفٌ قَدْ أَسَرُوا رَجُلَيْنِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏:‏ وَقَدْ قَالَ فِيمَا قَالَ ‏:‏ وَأَنَا مُسْلِمٌ أَوْ قَالَ ‏:‏ وَقَدْ أَسْلَمْتُ ‏.‏ فَلَمَّا مَضَى النَّبِيُّ صلى الله عليه وسلم - قَالَ أَبُو دَاوُدَ ‏:‏ فَهِمْتُ هَذَا مِنْ مُحَمَّدِ بْنِ عِيسَى - نَادَاهُ يَا مُحَمَّدُ يَا مُحَمَّدُ ‏.‏ قَالَ ‏:‏ وَكَانَ النَّبِيُّ صلى الله عليه وسلم رَحِيمًا رَفِيقًا فَرَجَعَ إِلَيْهِ قَالَ ‏:‏ ‏"‏ مَا شَأْنُكَ ‏"‏ ‏.‏ قَالَ ‏:‏ إِنِّي مُسْلِمٌ ‏.‏ قَالَ ‏:‏ ‏"‏ لَوْ قُلْتَهَا وَأَنْتَ تَمْلِكُ أَمْرَكَ أَفْلَحْتَ كُلَّ الْفَلاَحِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ ثُمَّ رَجَعْتُ إِلَى حَدِيثِ سُلَيْمَانَ قَالَ ‏:‏ يَا مُحَمَّدُ إِنِّي جَائِعٌ فَأَطْعِمْنِي إِنِّي ظَمْآنٌ فَاسْقِنِي ‏.‏ قَالَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏"‏ هَذِهِ حَاجَتُكَ ‏"‏ ‏.‏ أَوْ قَالَ ‏:‏ ‏"‏ هَذِهِ حَاجَتُهُ ‏"‏ ‏.‏ قَالَ ‏:‏ فَفُودِيَ الرَّجُلُ بَعْدُ بِالرَّجُلَيْنِ ‏.‏ قَالَ ‏:‏ وَحَبَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَضْبَاءَ لِرَحْلِهِ - قَالَ - فَأَغَارَ الْمُشْرِكُونَ عَلَى سَرْحِ الْمَدِينَةِ فَذَهَبُوا بِالْعَضْبَاءِ - قَالَ - فَلَمَّا ذَهَبُوا بِهَا وَأَسَرُوا امْرَأَةً مِنَ الْمُسْلِمِينَ - قَالَ - فَكَانُوا إِذَا كَانَ اللَّيْلُ يُرِيحُونَ إِبِلَهُمْ فِي أَفْنِيَتِهِمْ - قَالَ - فَنُوِّمُوا لَيْلَةً وَقَامَتِ الْمَرْأَةُ فَجَعَلَتْ لاَ تَضَعُ يَدَهَا عَلَى بَعِيرٍ إِلاَّ رَغَا حَتَّى أَتَتْ عَلَى الْعَضْبَاءِ - قَالَ - فَأَتَتْ عَلَى نَاقَةٍ ذَلُولٍ مُجَرَّسَةٍ - قَالَ - فَرَكِبَتْهَا ثُمَّ جَعَلَتْ لِلَّهِ عَلَيْهَا إِنْ نَجَّاهَا اللَّهُ لَتَنْحَرَنَّهَا - قَالَ - فَلَمَّا قَدِمَتِ الْمَدِينَةَ عُرِفَتِ النَّاقَةُ نَاقَةُ النَّبِيِّ صلى الله عليه وسلم فَأُخْبِرَ النَّبِيُّ صلى الله عليه وسلم بِذَلِكَ فَأَرْسَلَ إِلَيْهَا، فَجِيءَ بِهَا وَأُخْبِرَ بِنَذْرِهَا فَقَالَ ‏:‏ ‏"‏ بِئْسَمَا جَزَيْتِيهَا ‏"‏ ‏.‏ أَوْ ‏:‏ ‏"‏ جَزَتْهَا ‏"‏ ‏.‏ ‏:‏ ‏"‏ إِنِ اللَّهُ أَنْجَاهَا عَلَيْهَا لَتَنْحَرَنَّهَا، لاَ وَفَاءَ لِنَذْرٍ فِي مَعْصِيَةِ اللَّهِ وَلاَ فِيمَا لاَ يَمْلِكُ ابْنُ آدَمَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ وَالْمَرْأَةُ هَذِهِ امْرَأَةُ أَبِي ذَرٍّ ‏.‏\hadithno{3316}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1641)}\hadithtrans{Imran b. Husain said:'Adba belonged to a man of Banu 'Aqil. It used to go ahead of pligrims. The man was then captivated. He was brought in chains to the Prophet (ﷺ). The Prophet (ﷺ) was riding on a donkey with a blanket on him. He said: Muhammad, why do you arrest me and capture the one (i.e. the she-camel) which goes ahead of the pilgrims. He replied: We are arresting you on account of the crime committed by your allies Thaqid. Thaqif captivated two persons from among the Companions of the Prophet (ﷺ). He said (whatever he said) I am a Muslim, or he said: I have embraced Islam. When the Prophet (ﷺ) went ahead, he called him: O Muhammed, O Muhammed. Abu Dawud said: I learnt it from the version of the narrator Muhammad b. 'Isa. The Prophet (ﷺ) was compassionate and kind hearted. So he returned to him, and asked: What is the matter with you ? He replied: I am a Muslim. He said: Had you said it when the matter was in your hand, you would have succeeded completely. Abu Dawud said: I then returned to the version of the narrator Sulaiman (b. Harb). He said: Muhammad, I am hungry, so feed me. I am thirsty, so give me water. The Prophet (ﷺ) said: This is your need, or he said: This is his need (the narrator is doubtful). Later on the man was taken back (by Thaqif) as a ransom for the two men (of the Companions of the Prophet). The Prophet (ﷺ) retained 'Adba for his journey. The narrator said: The polytheists raided the pasturing animals of Medina and they took away 'Adba. When they took away 'Adba, they also captivated a Muslim woman. They used to leave their camels in the fields for rest at night. One night they slept and the (Muslim) woman stood up. Any camel on which she put her hand brayed until she came to 'Adba. She came to a she-camel which was docile and experienced. She then rode on her and vowed to Allah that if He saved her, she would sacrifice it. When she came to Medina, the people recognized the she-camel of the Prophet (ﷺ). The Prophet (ﷺ) was then informed about it and he sent for her. She was brought to him and she informed him about her vow. He said: It is a bad return that you have given it. Allah has not saved you, on its (back) that you now sacrifice it. A vow to do an act of disobedience must not be fulfilled, or to do something over which one has no control. Abu Dawud said: This woman was the wife of Abu Dharr}}
\hadithdefcmd{abudawud}{3317}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، وَابْنُ السَّرْحِ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، قَالَ قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ، - وَكَانَ قَائِدَ كَعْبٍ مِنْ بَنِيهِ حِينَ عَمِيَ - عَنْ كَعْبِ بْنِ مَالِكٍ، قَالَ قُلْتُ ‏:‏ يَا رَسُولَ اللَّهِ إِنَّ مِنْ تَوْبَتِي أَنْ أَنْخَلِعَ مِنْ مَالِي صَدَقَةً إِلَى اللَّهِ وَإِلَى رَسُولِهِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ أَمْسِكْ عَلَيْكَ بَعْضَ مَالِكَ فَهُوَ خَيْرٌ لَكَ ‏"‏ ‏.‏ قَالَ فَقُلْتُ ‏:‏ إِنِّي أُمْسِكُ سَهْمِيَ الَّذِي بِخَيْبَرَ ‏.‏\hadithno{3317}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ka'b ibn Malik: I said: Messenger of Allah, to make my repentance complete I should divest myself of my property as sadaqah (alms) for Allah and His Apostle. The Messenger of Allah (ﷺ) said: Retain some of your property, for that will be better for you. So he said: I shall retain the portion I have at Khaybar}}
\hadithdefcmd{abudawud}{3318}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ تِيبَ عَلَيْهِ ‏:‏ إِنِّي أَنْخَلِعُ مِنْ مَالِي ‏.‏ فَذَكَرَ نَحْوَهُ إِلَى ‏:‏ ‏ "‏ خَيْرٌ لَكَ ‏"‏ ‏.‏\hadithno{3318}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ka'b bin Malik:To the Messenger of Allah (ﷺ) when his repentance was accepted: I should divest myself of my property. He then mentioned a similar tradition up to the words, "better for you}}
\hadithdefcmd{abudawud}{3319}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ لِلنَّبِيِّ صلى الله عليه وسلم أَوْ أَبُو لُبَابَةَ أَوْ مَنْ شَاءَ اللَّهُ ‏:‏ إِنَّ مِنْ تَوْبَتِي أَنْ أَهْجُرَ دَارَ قَوْمِي الَّتِي أَصَبْتُ فِيهَا الذَّنْبَ، وَأَنْ أَنْخَلِعَ مِنْ مَالِي كُلِّهِ صَدَقَةً ‏.‏ قَالَ ‏:‏ ‏ "‏ يُجْزِئُ عَنْكَ الثُّلُثُ ‏"‏ ‏.‏\hadithno{3319}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ka'b ibn Malik: Ka'b ibn Malik said to AbuLubabah; or someone else whom Allah wished; or to the Prophet (ﷺ): To make my repentance complete I should depart from the house of my people in which I fell into sin, and that I should divest myself of all my property as sadaqah (alms). He said: A third (of your property) will be sufficient for you}}
\hadithdefcmd{abudawud}{3320}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنِي مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي ابْنُ كَعْبِ بْنِ مَالِكٍ، قَالَ ‏:‏ كَانَ أَبُو لُبَابَةَ، فَذَكَرَ مَعْنَاهُ وَالْقِصَّةُ لأَبِي لُبَابَةَ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ رَوَاهُ يُونُسُ عَنِ ابْنِ شِهَابٍ عَنْ بَعْضِ بَنِي السَّائِبِ بْنِ أَبِي لُبَابَةَ، وَرَوَاهُ الزُّبَيْدِيُّ عَنِ الزُّهْرِيِّ عَنْ حُسَيْنِ بْنِ السَّائِبِ بْنِ أَبِي لُبَابَةَ مِثْلَهُ ‏.‏\hadithno{3320}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{This tradition has also been transmitted by Ibn Ka'b b. Malik through a different chain of narrators. This version has:"He then mentioned the tradition to the same effect. This versions attributes this story to Abu Lubabah." Abu Dawud said: This tradition has been narrated by Yunus from Ibn Shihab from some of the children of al-Sa'ib son of Abu Lubabah. A similar tradition has also been transmitted by al-Zabidi from al-Zuhri from Husain b. al-Sa'ib son of Abu Lubabah}}
\hadithdefcmd{abudawud}{3321}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ قَالَ ابْنُ إِسْحَاقَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ كَعْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، فِي قِصَّتِهِ قَالَ قُلْتُ ‏:‏ يَا رَسُولَ اللَّهِ إِنَّ مِنْ تَوْبَتِي إِلَى اللَّهِ أَنْ أَخْرُجَ مِنْ مَالِي كُلِّهِ إِلَى اللَّهِ وَإِلَى رَسُولِهِ صَدَقَةً ‏.‏ قَالَ ‏:‏ ‏"‏ لاَ ‏"‏ ‏.‏ قُلْتُ ‏:‏ فَنِصْفَهُ ‏.‏ قَالَ ‏:‏ ‏"‏ لاَ ‏"‏ ‏.‏ قُلْتُ ‏:‏ فَثُلُثَهُ ‏.‏ قَالَ ‏:‏ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قُلْتُ ‏:‏ فَإِنِّي سَأُمْسِكُ سَهْمِي مِنْ خَيْبَرَ ‏.‏\hadithno{3321}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ka'b ibn Malik: I said: Messenger of Allah, to make my atonement complete I should divest myself of my all property as sadaqah (alms) for Allah and His apostle. He said: No. I said: The half of it. He said: No. I said: Then a third of it. He said: Yes. I said: I shall retain the portion I have at Khaybar}}
\hadithdefcmd{abudawud}{3322}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ التِّنِّيسِيُّ، عَنِ ابْنِ أَبِي فُدَيْكٍ، قَالَ حَدَّثَنِي طَلْحَةُ بْنُ يَحْيَى الأَنْصَارِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ مَنْ نَذَرَ نَذْرًا لَمْ يُسَمِّهِ فَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ، وَمَنْ نَذَرَ نَذْرًا فِي مَعْصِيَةٍ فَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ، وَمَنْ نَذَرَ نَذْرًا لاَ يُطِيقُهُ فَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ، وَمَنْ نَذَرَ نَذْرًا أَطَاقَهُ فَلْيَفِ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ رَوَى هَذَا الْحَدِيثَ وَكِيعٌ وَغَيْرُهُ عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي الْهِنْدِ أَوْقَفُوهُ عَلَى ابْنِ عَبَّاسٍ ‏.‏\hadithno{3322}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: If anyone takes a vow but does not name it, its atonement is the same as that for an oath, if anyone takes a vow to do an act of disobedience, its atonement is the same as that for an oath, if anyone takes a vow he is unable to fulfill, its atonement is the same as that for an oath, but if anyone takes a vow he is able to fulfill, he must do so. Abu Dawud said: This tradition has been transmitted by Waki' and others on the authority of 'Abd Allah b. Sa'id b. Abi al-Hind, but they traced it no farther back than Ibn 'Abbas}}
\hadithdefcmd{abudawud}{3323}{حَدَّثَنَا هَارُونُ بْنُ عَبَّادٍ الأَزْدِيُّ، حَدَّثَنَا أَبُو بَكْرٍ، - يَعْنِي ابْنَ عَيَّاشٍ - عَنْ مُحَمَّدٍ، مَوْلَى الْمُغِيرَةِ قَالَ حَدَّثَنِي كَعْبُ بْنُ عَلْقَمَةَ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏ "‏ كَفَّارَةُ النَّذْرِ كَفَّارَةُ الْيَمِينِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏:‏ وَرَوَاهُ عَمْرُو بْنُ الْحَارِثِ عَنْ كَعْبِ بْنِ عَلْقَمَةَ عَنِ ابْنِ شِمَاسَةَ عَنْ عُقْبَةَ ‏.‏\hadithno{3323}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Uqbah bin 'Amir: The Messenger of Allah (ﷺ) as saying: The atonement for a vow is the same as for an oath. Abu Dawud said: This tradition has also been transmitted by 'Amr b. al-Harith from Ka'b b. 'Alqamah, from Ibn Shamasah on the authority of 'Uqbah}}
\hadithdefcmd{abudawud}{3324}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ، أَنَّ سَعِيدَ بْنَ الْحَكَمِ، حَدَّثَهُمْ أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنِي كَعْبُ بْنُ عَلْقَمَةَ، أَنَّهُ سَمِعَ ابْنَ شِمَاسَةَ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{3324}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{A similar tradition has also been transmitted by 'Uqbah b. 'Amir from the Prophet (ﷺ) through a different chain of narrators}}
\hadithdefcmd{abudawud}{3325}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، رَضِيَ اللَّهُ عَنْهُ أَنَّهُ قَالَ ‏:‏ يَا رَسُولَ اللَّهِ إِنِّي نَذَرْتُ فِي الْجَاهِلِيَّةِ أَنْ أَعْتَكِفَ فِي الْمَسْجِدِ الْحَرَامِ لَيْلَةً ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏:‏ ‏ "‏ أَوْفِ بِنَذْرِكَ ‏"‏ ‏.‏\hadithno{3325}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2032) Sahih Muslim (1656)}\hadithtrans{Narrated Ibn 'Umar:That 'Umar said: Messenger of Allah, I took a vow in pre-Islamic times that I would stay in the sacred mosque (Masjid Haram) as a devotion (i'tikaf). The Prophet (ﷺ) said: Fulfill your vow}}
